==> notolog-0.9.1b8-py3-none-any.whl: notolog/lexemes/gr/settings_dialog.py <==
# Greek lexemes settings_dialog.py
lexemes = {
    # Διάλογος ρυθμίσεων
    "window_title": "Ρυθμίσεις",

    "button_close": "Κλείσιμο",

    "tab_general": "Γενικά",
    "tab_editor_config": "Επεξεργαστής",
    "tab_viewer_config": "Προβολέας",
    "tab_ai_config": "Ρυθμίσεις AI",

    "general_app_config_label": "Ρυθμίσεις Εφαρμογής",
    "general_app_language_label": "Γλώσσα",
    "general_app_language_combo_placeholder_text": "Επιλέξτε γλώσσα",
    "general_app_language_combo_accessible_description": "Γλώσσα διεπαφής της εφαρμογής",
    "general_app_theme_label": "Θέμα",
    "general_app_theme_combo_placeholder_text": "Επιλέξτε θέμα",
    "general_app_theme_combo_accessible_description": "Θέμα διεπαφής της εφαρμογής",
    "general_app_main_menu_label": "Κύριο Μενού",
    "general_app_main_menu_checkbox": "Εμφάνιση Κύριου Μενού",
    "general_app_main_menu_checkbox_accessible_description": "Εμφάνιση του κύριου αναδυόμενου μενού της εφαρμογής",
    "general_app_font_size_label": "Μέγεθος Γραμματοσειράς: {size}pt",
    "general_app_font_size_slider_accessible_description":
        "Ρύθμιση του παγκόσμιου μεγέθους γραμματοσειράς της εφαρμογής",

    "general_statusbar_label": "Γραμμή Κατάστασης",
    "general_statusbar_show_global_cursor_position_checkbox": "Εμφάνιση Παγκόσμιας Θέσης Δρομέα",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Εμφάνιση της παγκόσμιας θέσης του δρομέα στη γραμμή κατάστασης",

    "editor_config_label": "Ρυθμίσεις Επεξεργαστή",
    "editor_config_show_line_numbers_checkbox": "Εμφάνιση Αριθμών Γραμμών",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Εμφάνιση αριθμών γραμμών στον επεξεργαστή",

    "viewer_config_label": "Ρυθμίσεις Προβολέα",
    "viewer_config_process_emojis_checkbox": "Μετατροπή Εικονιδίων Κειμένου σε Γραφικά",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Μετατροπή εικονιδίων κειμένου σε γραφικές αναπαραστάσεις",
    "viewer_config_highlight_todos_checkbox": "Επισήμανση Σημειώσεων TODO",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Επισήμανση ετικετών TODO μέσα στο κείμενο",
    "viewer_config_open_link_confirmation_checkbox": "Απαίτηση Επιβεβαίωσης για Άνοιγμα Συνδέσμων",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Ζήτηση επιβεβαίωσης πριν το άνοιγμα συνδέσμων",
    "viewer_config_save_resources_checkbox": "Αυτόματη αποθήκευση εξωτερικών εικόνων στον δίσκο",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Αυτόματη αποθήκευση αντιγράφων εξωτερικών εικόνων στον δίσκο για πρόσβαση χωρίς σύνδεση.",

    "ai_config_openai_api_label": "OpenAI API",
    "ai_config_openai_api_url_input_placeholder_text": "URL API",
    "ai_config_openai_api_url_input_accessible_description": "URL του OpenAI API",
    "ai_config_openai_api_key_input_placeholder_text": "Κλειδί API",
    "ai_config_openai_api_key_input_accessible_description": "Κλειδί του OpenAI API",
    "ai_config_openai_api_supported_models_label": "Υποστηριζόμενα μοντέλα",
    "ai_config_ai_model_names_combo_placeholder_text": "Επιλέξτε μοντέλο",
    "ai_config_ai_model_names_combo_accessible_description": "Υποστηριζόμενα μοντέλα προς επιλογή",

    "ai_config_base_label": "Βασικοί Παράμετροι",
    "ai_config_base_system_prompt_label": "Σύστημα Προτροπής",
    "ai_config_base_system_prompt_edit_placeholder_text": "Βασική προτροπή συστήματος που προηγείται κάθε αιτήματος",
    "ai_config_base_system_prompt_edit_accessible_description":
        "Βασική προτροπή συστήματος που προηγείται κάθε αιτήματος. Απλό κείμενο.",
    "ai_config_base_response_max_tokens_label": "Μέγιστοι Διακριτικοί Απόκρισης",
    "ai_config_base_response_max_tokens_input_accessible_description":
        "Μέγιστος αριθμός διακριτικών για λήψη σε απόκριση",
}

==> notolog-1.0.0-py3-none-any.whl: notolog/lexemes/gr/settings_dialog.py <==
# Greek lexemes settings_dialog.py
lexemes = {
    # Διάλογος ρυθμίσεων
    "window_title": "Ρυθμίσεις",

    "button_close": "Κλείσιμο",

    "tab_general": "Γενικά",
    "tab_editor_config": "Επεξεργαστής",
    "tab_viewer_config": "Προβολέας",
    "tab_ai_config": "Ρυθμίσεις AI",

    "general_app_config_label": "Ρυθμίσεις Εφαρμογής",
    "general_app_language_label": "Γλώσσα",
    "general_app_language_combo_placeholder_text": "Επιλέξτε γλώσσα",
    "general_app_language_combo_accessible_description": "Γλώσσα διεπαφής της εφαρμογής",
    "general_app_theme_label": "Θέμα",
    "general_app_theme_combo_placeholder_text": "Επιλέξτε θέμα",
    "general_app_theme_combo_accessible_description": "Θέμα διεπαφής της εφαρμογής",
    "general_app_main_menu_label": "Κύριο Μενού",
    "general_app_main_menu_checkbox": "Εμφάνιση Κύριου Μενού",
    "general_app_main_menu_checkbox_accessible_description": "Εμφάνιση του κύριου αναδυόμενου μενού της εφαρμογής",
    "general_app_font_size_label": "Μέγεθος Γραμματοσειράς: {size}pt",
    "general_app_font_size_slider_accessible_description":
        "Ρύθμιση του παγκόσμιου μεγέθους γραμματοσειράς της εφαρμογής",

    "general_statusbar_label": "Γραμμή Κατάστασης",
    "general_statusbar_show_global_cursor_position_checkbox": "Εμφάνιση Παγκόσμιας Θέσης Δρομέα",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Εμφάνιση της παγκόσμιας θέσης του δρομέα στη γραμμή κατάστασης",

    "editor_config_label": "Ρυθμίσεις Επεξεργαστή",
    "editor_config_show_line_numbers_checkbox": "Εμφάνιση Αριθμών Γραμμών",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Εμφάνιση αριθμών γραμμών στον επεξεργαστή",

    "viewer_config_label": "Ρυθμίσεις Προβολέα",
    "viewer_config_process_emojis_checkbox": "Μετατροπή Εικονιδίων Κειμένου σε Γραφικά",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Μετατροπή εικονιδίων κειμένου σε γραφικές αναπαραστάσεις",
    "viewer_config_highlight_todos_checkbox": "Επισήμανση Σημειώσεων TODO",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Επισήμανση ετικετών TODO μέσα στο κείμενο",
    "viewer_config_open_link_confirmation_checkbox": "Απαίτηση Επιβεβαίωσης για Άνοιγμα Συνδέσμων",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Ζήτηση επιβεβαίωσης πριν το άνοιγμα συνδέσμων",
    "viewer_config_save_resources_checkbox": "Αυτόματη αποθήκευση εξωτερικών εικόνων στον δίσκο",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Αυτόματη αποθήκευση αντιγράφων εξωτερικών εικόνων στον δίσκο για πρόσβαση χωρίς σύνδεση.",

    "ai_config_inference_module_label": "Μονάδα συμπερασμάτων",
    "ai_config_inference_module_names_combo_placeholder_text": "Επιλέξτε μονάδα",
    "ai_config_inference_module_names_combo_accessible_description": "Διαθέσιμες μονάδες για επιλογή",

    "ai_config_multi_turn_dialogue_checkbox":
        "Πολυστροφικός διάλογος που βασίζεται σε προηγούμενες εντολές για συνεχή πλαίσιο",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Πολυστροφικός διάλογος που βασίζεται σε προηγούμενες εντολές για συνεχή πλαίσιο",
    "ai_config_convert_to_md_checkbox": "Μετατροπή του αποτελέσματος σε Markdown",
    "ai_config_convert_to_md_checkbox_accessible_description": "Μετατροπή του μηνύματος αποτελέσματος σε Markdown",

    "ai_config_base_label": "Βασικοί Παράμετροι",
}
